@@ -2,12 +2,13 @@
 """ This module is named python module.py and bring you function print_lol. In this function, you can find list
       type element and show them as data."""
 
-def print_lol(the_list, level=0) :
+def print_lol(the_list, indent=False, level=0) :
     for each_item in the_list :
         if isinstance(each_item, list) :
-            print_lol(each_item, level + 1)
+            print_lol(each_item, indent, level + 1)
         else :
-            for tab_stop in range(level) :
-                print("\t",end='')
+            if indent :
+                for tab_stop in range(level) :
+                    print("\t",end='')
             print(each_item)
 
